import os
from llama_index import download_loader
import logging
from llama_index import (
        KnowledgeGraphIndex,
        ServiceContext,
        )
from llama_index.storage.storage_context import StorageContext
from llama_index.graph_stores import SparqlGraphStore
from llama_index.llms import OpenAI
from llama_index import load_index_from_storage
import openai

openai.api_key = os.environ["OPENAI_API_KEY"];

llm = OpenAI(temperature=0, model="text-davinci-002")
service_context = ServiceContext.from_defaults(llm=llm, chunk_size=512)

ENDPOINT = 'http://localhost:8890/sparql-auth/'
GRAPH = 'http://purl.org/stuff/guardians'
BASE_URI = 'http://purl.org/stuff/data'
USER = 'dba'
PASSWORD = 'dba'

graph_store = SparqlGraphStore(
        sparql_endpoint=ENDPOINT,
        sparql_graph=GRAPH,
        sparql_base_uri=BASE_URI,
        create_graph=False,
        user_name=USER,
        user_password=PASSWORD,
        )
storage_context = StorageContext.from_defaults(graph_store=graph_store)

WikipediaReader = download_loader("WikipediaReader")
loader = WikipediaReader()
documents = loader.load_data(
        pages=['Barbie (film)'], auto_suggest=False)

kg_index = KnowledgeGraphIndex.from_documents(
        documents,
        storage_context=storage_context,
        service_context=service_context,
        max_triplets_per_chunk=10,
        sparql_endpoint=ENDPOINT,
        sparql_graph=GRAPH,
        sparql_base_uri=BASE_URI,
        include_embeddings=True,
        )

kg_index.storage_context.persist(persist_dir='./llama_storage_graph')

kg_rag_query_engine = kg_index.as_query_engine(
        include_text=False,
        retriever_mode="keyword",
        response_mode="tree_summarize",
        )

response_graph_rag = kg_rag_query_engine.query("In the movie, what does Barbie think about?")

print(str(response_graph_rag))

